@@ -24,20 +24,20 @@ test_that("SDA properties (dominant condition) works", {
                         method = "Dominant Condition",
                         areasymbols = target_areas)
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows - n_misc_area_rows)
+  expect_equivalent(nrow(x), target_area_rows - n_misc_area_rows)
 
   x <- get_SDA_property(property = "Taxonomic Suborder",
                         method = "Dominant Condition",
                         areasymbols = target_areas,
                         miscellaneous_areas = TRUE)
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows)
+  expect_equivalent(nrow(x), target_area_rows)
 
   x <- get_SDA_property(property = c("Taxonomic Suborder","Taxonomic Order"),
                    method = "Dominant Condition",
                    mukeys = target_mukeys)
   skip_if(is.null(x))
-  expect_equal(x$mukey, target_mukeys)
+  expect_equivalent(x$mukey, target_mukeys)
 
 })
 
@@ -53,13 +53,13 @@ test_that("SDA properties (dominant component category) works", {
                         method = "Dominant Component (Category)",
                         areasymbols = target_areas)
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows - n_misc_area_rows)
+  expect_equivalent(nrow(x), target_area_rows - n_misc_area_rows)
 
   x <- get_SDA_property(property = c("Taxonomic Suborder","Taxonomic Order"),
                         method = "Dominant Component (Category)",
                         mukeys = target_mukeys)
   skip_if(is.null(x))
-  expect_equal(x$mukey, target_mukeys)
+  expect_equivalent(x$mukey, target_mukeys)
 })
 
 test_that("SDA properties (dominant component numeric) works", {
@@ -78,7 +78,7 @@ test_that("SDA properties (dominant component numeric) works", {
     bottom_depth = 50
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows)
+  expect_equivalent(nrow(x), target_area_rows)
 
   x <- get_SDA_property(
     property = c("sandvc_l","sandvc_r","sandvc_h"),
@@ -88,7 +88,7 @@ test_that("SDA properties (dominant component numeric) works", {
     bottom_depth = 50
   )
   skip_if(is.null(x))
-  expect_equal(x$mukey, target_mukeys)
+  expect_equivalent(x$mukey, target_mukeys)
 
   # dominant component of 1st mapunit is rock outcrop (excluded), pH 5 from Thermalrocks 10-13cm
   # dominant component of 2nd mapunit is very shallow soil with R at 10cm
@@ -99,8 +99,8 @@ test_that("SDA properties (dominant component numeric) works", {
                         include_minors = TRUE,
                         top_depth = 10,
                         bottom_depth = 20)
-  expect_equal(x$ph1to1h2o_r, c(5, NA))
-  expect_equal(x$claytotal_r, c(22, NA))
+  expect_equivalent(x$ph1to1h2o_r, c(5, NA))
+  expect_equivalent(x$claytotal_r, c(22, NA))
 })
 
 test_that("SDA properties (weighted average) works", {
@@ -128,7 +128,7 @@ test_that("SDA properties (weighted average) works", {
     bottom_depth = 50
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows)
+  expect_equivalent(nrow(x), target_area_rows)
 
   x <- get_SDA_property(
     property = c("claytotal_l","claytotal_r","claytotal_h"),
@@ -139,7 +139,7 @@ test_that("SDA properties (weighted average) works", {
   )
 
   skip_if(is.null(x))
-  expect_equal(x$mukey, target_mukeys)
+  expect_equivalent(x$mukey, target_mukeys)
 
   # check miscellaneous areas and NULL data in horizons
   x <- get_SDA_property(property = c("ph1to1h2o_r", "claytotal_r"),
@@ -248,7 +248,7 @@ test_that("SDA properties (min/max) works", {
     miscellaneous_areas = TRUE
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows)
+  expect_equivalent(nrow(x), target_area_rows)
 
   x <- get_SDA_property(
     property = "Saturated Hydraulic Conductivity - Rep Value",
@@ -257,7 +257,7 @@ test_that("SDA properties (min/max) works", {
     FUN = "MIN"
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows)
+  expect_equivalent(nrow(x), target_area_rows)
   
   # 463263      Daulton loam, 15 to 30 percent slopes
   # 463264      Daulton very rocky loam, 15 to 30 percent slopes
@@ -270,7 +270,7 @@ test_that("SDA properties (min/max) works", {
     miscellaneous_areas = TRUE
   )
   skip_if(is.null(x))
-  expect_equal(x$mukey, target_mukeys)
+  expect_equivalent(x$mukey, target_mukeys)
 })
 
 test_that("SDA properties (no aggregation) works", {
@@ -289,7 +289,7 @@ test_that("SDA properties (no aggregation) works", {
       miscellaneous_areas = FALSE
     )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows_all - n_misc_area_rows_all)
+  expect_equivalent(nrow(x), target_area_rows_all - n_misc_area_rows_all)
 
   x <- get_SDA_property(
     property = c('rsprod_l', 'rsprod_r', 'rsprod_h'),
@@ -298,7 +298,7 @@ test_that("SDA properties (no aggregation) works", {
     miscellaneous_areas = TRUE
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows_all)
+  expect_equivalent(nrow(x), target_area_rows_all)
 
 
   # return results 1:1 with chorizon for horizon properties (includes cokey)
@@ -308,7 +308,7 @@ test_that("SDA properties (no aggregation) works", {
     areasymbols = target_areas
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows_all_chorizon - n_misc_area_rows_all_chorizon)
+  expect_equivalent(nrow(x), target_area_rows_all_chorizon - n_misc_area_rows_all_chorizon)
 
   x <- get_SDA_property(
     c('sandtotal_l', 'sandtotal_r', 'sandtotal_h'),
@@ -317,5 +317,5 @@ test_that("SDA properties (no aggregation) works", {
     miscellaneous_areas = TRUE
   )
   skip_if(is.null(x))
-  expect_equal(nrow(x), target_area_rows_all_chorizon)
+  expect_equivalent(nrow(x), target_area_rows_all_chorizon)
 })
